@@ -1,2 +1,3 @@
 from ansi2html.converter import Ansi2HTMLConverter
-__all__ = ['Ansi2HTMLConverter']
+
+__all__ = ["Ansi2HTMLConverter"]
